Index: components/policy/core/common/configuration_policy_provider_test.h |
diff --git a/components/policy/core/common/configuration_policy_provider_test.h b/components/policy/core/common/configuration_policy_provider_test.h |
index a8a0d4316b71b96a3765767c5bcc882318d62c13..60bc6e402ef54a942d71f526e1dca86429044f78 100644 |
--- a/components/policy/core/common/configuration_policy_provider_test.h |
+++ b/components/policy/core/common/configuration_policy_provider_test.h |
@@ -65,9 +65,11 @@ class PolicyTestBase : public testing::Test { |
// ConfigurationPolicyProviderTest below. |
class PolicyProviderTestHarness { |
public: |
- // |level| and |scope| are the level and scope of the policies returned by |
- // the providers from CreateProvider(). |
- PolicyProviderTestHarness(PolicyLevel level, PolicyScope scope); |
+ // |level|, |scope| and |source| are the level, scope and source of the |
+ // policies returned by the providers from CreateProvider(). |
+ PolicyProviderTestHarness(PolicyLevel level, |
+ PolicyScope scope, |
+ PolicySource source); |
virtual ~PolicyProviderTestHarness(); |
// Actions to run at gtest SetUp() time. |
@@ -78,9 +80,10 @@ class PolicyProviderTestHarness { |
SchemaRegistry* registry, |
scoped_refptr<base::SequencedTaskRunner> task_runner) = 0; |
// Returns the policy level and scope set by the policy provider. |
PolicyLevel policy_level() const; |
PolicyScope policy_scope() const; |
+ PolicySource policy_source() const; |
// Helpers to configure the environment the policy provider reads from. |
virtual void InstallEmptyPolicy() = 0; |
@@ -103,6 +106,7 @@ class PolicyProviderTestHarness { |
private: |
PolicyLevel level_; |
PolicyScope scope_; |
+ PolicySource source_; |
DISALLOW_COPY_AND_ASSIGN(PolicyProviderTestHarness); |
}; |
@@ -78,9 +80,10 @@ class PolicyProviderTestHarness { |
SchemaRegistry* registry, |
scoped_refptr<base::SequencedTaskRunner> task_runner) = 0; |
- // Returns the policy level and scope set by the policy provider. |
+ // Returns the policy level, scope and source set by the policy provider. |
PolicyLevel policy_level() const; |
PolicyScope policy_scope() const; |